from VXperdeepke import KeywordExtraction

text = "بر اساس تحلیل نقشه‌های همدیدی و آینده‌نگری سازمان هواشناسی امروز در استان‌های ساحلی دریای خزر، اردبیل، شمال آذربایجان شرقی و ارتفاعات البرز مرکزی بارش باران، همراه با وزش باد شدید موقتی و کاهش نسبی دما پیش‌بینی شده است. فردا از میزان بارش‌های این مناطق کاسته شده و فقط در سواحل شمالی بارش پراکنده روی می‌دهد."
segment_num = 3
top_n = 5

ke = KeywordExtraction()
ke.load_model()
word_score = ke.infer(text, segment_num= segment_num, top_n= top_n)

print(word_score)

"""
test output:

[('آینده\u200cنگری', 4.234069764614105), ('استان\u200cهای', 4.143936276435852), ('بارش\u200cهای', 4.121438443660736), ('نقشه\u200cهای', 4.015317618846893), ('دریای', 3.9617764949798584), ('شمالی', 3.9322071075439453)] 
"""